@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*-----------------------------------------------------------------------
@@ -563,13 +563,11 @@ static int FindTimeSeriesStartAndEnd (
   UINT4 flag, safe = 1;
   UINT4 length;
 
-#ifndef LAL_NDEBUG
   if ( !signalvec )
     XLAL_ERROR( XLAL_EFAULT );
 
   if ( !signalvec->data )
     XLAL_ERROR( XLAL_EFAULT );
-#endif
 
   length = signalvec->length;
 
