@@ -13,8 +13,8 @@
 *
 *  You should have received a copy of the GNU General Public License
 *  along with with program; see the file COPYING. If not, write to the
-*  Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-*  MA  02111-1307  USA
+*  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+*  MA  02110-1301  USA
 */
 
 /*----------------------------------------------------------------------------
@@ -39,20 +39,20 @@
  * ### Description ###
  *
  * <tt>XLALTrigScanClusterTriggers()</tt> is the main function for invoking
- * trigScan clustering. It takes in the ::SnglInspiralTable to be clustered,
+ * trigScan clustering. It takes in the \c SnglInspiralTable to be clustered,
  * the method to be applied, the metric scaling factor, and a flag to say whether
  * to append stragglers (i.e. clusters of only 1 trigger). Upon success, the
- * return value will be #XLAL_SUCCESS, with the ::SnglInspiralTable having
+ * return value will be #XLAL_SUCCESS, with the \c SnglInspiralTable having
  * been clustered. At present, the only clustering method implemented is #T0T3Tc.
  *
- * <tt>XLALTrigScanCreateCluster()</tt> takes in a ::TriggerErrorList
+ * <tt>XLALTrigScanCreateCluster()</tt> takes in a \c TriggerErrorList
  * containing the triggers, their position vectors and ellipsoid matrices. It
  * creates the cluster by agglomerating triggers by checking for overlap of
  * ellipsoids. Upon ellipsoid overlap, the trigger is added to the cluster, and
  * removed from the unclustered list.
  *
  * <tt>XLALTrigScanRemoveStragglers()</tt> takes in a linked list of
- * ::TrigScanCluster's. It removes all clusters of 1 element from the list.
+ * \c TrigScanCluster's. It removes all clusters of 1 element from the list.
  *
  * <tt>XLALTrigScanKeepLoudestTrigger()</tt> performs the actual clustering,
  * freeing all triggers in the cluster except the loudest. Currently, loudest
@@ -61,12 +61,12 @@
  *
  * <tt>XLALTrigScanReLinkLists()</tt> re-links all the inter-cluster lists after
  * the clustering has been performed, in preparation for returning the clustered
- * ::SnglInspiralTable to the program.
+ * \c SnglInspiralTable to the program.
  *
  * <tt>XLALTrigScanDestroyCluster()</tt> frees memory associated with a cluster.
- * It has two modes of operation, specified by the ::TrigScanStatus. If this
- * is #TRIGSCAN_ERROR, the ::SnglInspiralTable will also be freed. If it is
- * #TRIGSCAN_SUCCESS, the ::SnglInspiralTable will be kept for returning to the
+ * It has two modes of operation, specified by the \c TrigScanStatus. If this
+ * is #TRIGSCAN_ERROR, the \c SnglInspiralTable will also be freed. If it is
+ * #TRIGSCAN_SUCCESS, the \c SnglInspiralTable will be kept for returning to the
  * calling program.
  *
  */
@@ -86,7 +86,6 @@ int XLALTrigScanClusterTriggers( SnglInspiralTable **table,
   /* The maximum time difference associated with an ellipsoid */
   REAL8 tcMax;
 
-#ifndef LAL_NDEBUG
   if ( !table )
   {
     XLAL_ERROR( XLAL_EFAULT );
@@ -96,7 +95,6 @@ int XLALTrigScanClusterTriggers( SnglInspiralTable **table,
   {
     XLAL_ERROR( XLAL_EINVAL );
   }
-#endif
 
   tableHead = *table;
 
@@ -279,7 +277,6 @@ TrigScanCluster * XLALTrigScanCreateCluster( TriggerErrorList **errorListHead,
   fContactWorkSpace *workSpace        = NULL;
   REAL8             fContactValue;
 
-#ifndef LAL_NDEBUG
   if ( !errorListHead )
   {
     XLAL_ERROR_NULL( XLAL_EFAULT );
@@ -294,7 +291,6 @@ TrigScanCluster * XLALTrigScanCreateCluster( TriggerErrorList **errorListHead,
   {
     XLAL_ERROR_NULL( XLAL_EINVAL );
   }
-#endif
 
   /* Allocate memory for the cluster */
   cluster = LALCalloc( 1, sizeof( TrigScanCluster ) );
@@ -372,7 +368,7 @@ TrigScanCluster * XLALTrigScanCreateCluster( TriggerErrorList **errorListHead,
         {
           TriggerErrorList *tmpClusterList = thisClusterList;
           thisClusterList = thisClusterList->next;
-          XLALFreeSnglInspiral( &(tmpClusterList->trigger) );
+          XLALDestroySnglInspiralTableRow( tmpClusterList->trigger );
           XLAL_CALLGSL( gsl_matrix_free( tmpClusterList->err_matrix ) );
           XLAL_CALLGSL( gsl_vector_free( tmpClusterList->position ) );
           LALFree( tmpClusterList );
@@ -436,12 +432,10 @@ int XLALTrigScanRemoveStragglers( TrigScanCluster **clusters )
   TrigScanCluster *previous    = NULL; /* Keeping track of the previous element */
   TrigScanCluster *thisCluster = NULL;
 
-#ifndef LAL_NDEBUG
   if ( !clusters )
   {
     XLAL_ERROR( XLAL_EFAULT );
   }
-#endif
 
   /* Loop through the list and remove all clusters containing 1 trigger */
   while ( thisCluster )
@@ -460,7 +454,7 @@ int XLALTrigScanRemoveStragglers( TrigScanCluster **clusters )
       {
         previous->next = tmpCluster->next;
       }
-      XLALFreeSnglInspiral( &(tmpCluster->element->trigger) );
+      XLALDestroySnglInspiralTableRow( tmpCluster->element->trigger );
       XLAL_CALLGSL( gsl_matrix_free( tmpCluster->element->err_matrix ) );
       XLAL_CALLGSL( gsl_vector_free( tmpCluster->element->position ) );
       LALFree( tmpCluster );
@@ -481,7 +475,6 @@ int XLALTrigScanKeepLoudestTrigger( TrigScanCluster *cluster )
   TriggerErrorList *triggerToKeep;
   TriggerErrorList *thisTrigger;
 
-#ifndef LAL_NDEBUG
   if ( !cluster )
   {
     XLAL_ERROR( XLAL_EFAULT );
@@ -492,7 +485,6 @@ int XLALTrigScanKeepLoudestTrigger( TrigScanCluster *cluster )
     XLALPrintError( "Invalid number of triggers in cluster: %d\n", cluster->nelements );
     XLAL_ERROR( XLAL_EINVAL );
   }
-#endif
 
   if ( cluster->nelements == 1 )
   {
@@ -520,7 +512,7 @@ int XLALTrigScanKeepLoudestTrigger( TrigScanCluster *cluster )
 
     if ( tmpTrigger != triggerToKeep )
     {
-      XLALFreeSnglInspiral( &(tmpTrigger->trigger ) );
+      XLALDestroySnglInspiralTableRow( tmpTrigger->trigger );
       XLAL_CALLGSL( gsl_matrix_free( tmpTrigger->err_matrix ) );
       XLAL_CALLGSL( gsl_vector_free( tmpTrigger->position ) );
       LALFree( tmpTrigger );
@@ -561,20 +553,18 @@ void XLALTrigScanDestroyCluster( TrigScanCluster *cluster,
 {
   TriggerErrorList *thisList;
 
-#ifndef LAL_NDEBUG
   if ( !cluster )
     XLAL_ERROR_VOID( XLAL_EFAULT );
 
   if ( (UINT4) status >= (UINT4) TRIGSCAN_NUM_STATUS )
     XLAL_ERROR_VOID( XLAL_EINVAL );
-#endif
 
   /* If something has failed, we need to free the SnglInspirals */
   if ( status == TRIGSCAN_ERROR )
   {
     for ( thisList = cluster->element; thisList; thisList = thisList->next )
     {
-      XLALFreeSnglInspiral( &(thisList->trigger ) );
+      XLALDestroySnglInspiralTableRow( thisList->trigger );
     }
   }
 
