@@ -24,11 +24,9 @@
 #
 
 
-from __future__ import print_function
 import itertools
 import math
 import operator
-import sys
 
 
 from ligo.lw import ligolw
@@ -43,66 +41,11 @@ from .git_version import date as __date__
 from .git_version import version as __version__
 
 
-#
-# =============================================================================
-#
-#                                 Speed Hacks
-#
-# =============================================================================
-#
-
-
-#
-# Construct a subclass of the sngl_inspiral row class with the methods that
-# are needed
-#
-
-
-class SnglInspiral(lsctables.SnglInspiral):
-	__slots__ = ()
-
-	#
-	# compare self's end time to the LIGOTimeGPS instance other.
-	# allows bisection searches by GPS time to find ranges of triggers
-	# quickly
-	#
-
-	def __lt__(self, other):
-		return self.end < other
-
-	def __le__(self, other):
-		return self.end <= other
-
-	def __eq__(self, other):
-		return self.end == other
-
-	def __ne__(self, other):
-		return self.end != other
-
-	def __ge__(self, other):
-		return self.end >= other
-
-	def __gt__(self, other):
-		return self.end > other
-
-	#
-	# simulate mtotal, eta, and mchirp from mass1 and mass2.  this (a)
-	# works around documents that have incorrect values in those three
-	# columns (yes, yes people do that) and (b) allows us to process
-	# documents that don't have the columns at all
-	#
-
-	@property
-	def mtotal(self):
-		return self.mass1 + self.mass2
-
-	@property
-	def eta(self):
-		return self.mass1 * self.mass2 / self.mtotal**2.
-
-	@property
-	def mchirp(self):
-		return self.mtotal * self.eta**0.6
+def mchirp(m1, m2):
+	# mchirp = mtotal * eta**0.6
+	#        = mtotal * ((m1 * m2) / mtotal**2)**0.6
+	mtotal = m1 + m2
+	return mtotal * ((m1 * m2) / (mtotal * mtotal))**0.6
 
 
 #
@@ -119,7 +62,7 @@ class SnglInspiral(lsctables.SnglInspiral):
 #
 
 
-InspiralCoincDef = lsctables.CoincDef(search = u"inspiral", search_coinc_type = 0, description = u"sngl_inspiral<-->sngl_inspiral coincidences")
+InspiralCoincDef = lsctables.CoincDef(search = "inspiral", search_coinc_type = 0, description = "sngl_inspiral<-->sngl_inspiral coincidences")
 
 
 #
@@ -173,7 +116,7 @@ class InspiralCoincTables(snglcoinc.CoincTables):
 
 
 	def coinc_rows(self, process_id, time_slide_id, events, seglists):
-		coinc, coincmaps = super(InspiralCoincTables, self).coinc_rows(process_id, time_slide_id, events, u"sngl_inspiral")
+		coinc, coincmaps = super(InspiralCoincTables, self).coinc_rows(process_id, time_slide_id, events, "sngl_inspiral")
 
 		#
 		# populate the coinc_inspiral table.  assume exact-match
@@ -201,7 +144,7 @@ class InspiralCoincTables(snglcoinc.CoincTables):
 		coinc_inspiral = self.coinc_inspiral_table.RowType(
 			coinc_event_id = coinc.coinc_event_id,	# = None
 			mass = refevent.mass1 + refevent.mass2,
-			mchirp = refevent.mchirp,
+			mchirp = mchirp(refevent.mass1, refevent.mass2),
 			snr = math.sqrt(sum(event.snr**2. for event in events)),
 			false_alarm_rate = None,
 			combined_far = None,
@@ -267,18 +210,15 @@ def ligolw_thinca(
 	seglists,
 	ntuple_comparefunc = None,
 	veto_segments = None,
-	likelihood_func = None,
-	fapfar = None,
 	min_instruments = 2,
 	coinc_definer_row = InspiralCoincDef,
+	incremental = True,
 	verbose = False
 ):
 	#
 	# prepare the coincidence table interface.
 	#
 
-	if verbose:
-		print("indexing ...", file=sys.stderr)
 	coinc_tables = InspiralCoincTables(xmldoc, coinc_definer_row)
 
 	#
@@ -297,26 +237,34 @@ def ligolw_thinca(
 		sngl_inspiral_table = (event for event in sngl_inspiral_table if event.ifo not in veto_segments or event.end not in veto_segments[event.ifo])
 		# don't do in-place
 		seglists = seglists - veto_segments
-	for instrument, events in itertools.groupby(sorted(sngl_inspiral_table, key = lambda row: row.ifo), lambda event: event.ifo):
-		events = tuple(events)
-		time_slide_graph.push(instrument, events, max(event.end for event in events))
 
 	#
-	# retrieve all coincidences, apply the final n-tuple compare func
-	# and record the survivors
+	# push into coincidence graph and collect candidates
 	#
 
-	for node, events in time_slide_graph.pull(coinc_sieve = ntuple_comparefunc, flush = True, verbose = verbose):
-		coinc, coincmaps, coinc_inspiral = coinc_tables.coinc_rows(process_id, node.time_slide_id, events, seglists = seglists)
-		if likelihood_func is not None:
-			coinc.likelihood = likelihood_func(events, node.offset_vector)
-			if fapfar is not None:
-				# FIXME:  add proper columns to
-				# store these values in
-				coinc_inspiral.combined_far = fapfar.far_from_rank(coinc.likelihood)
-				coinc_inspiral.false_alarm_rate = fapfar.fap_from_rank(coinc.likelihood)
-		# finally, append coinc to tables
-		coinc_tables.append_coinc(coinc, coincmaps, coinc_inspiral)
+	if not incremental:
+		# normal version:  push everything into the graph, then
+		# pull out all coincs in one operation below using the
+		# final flush
+		for instrument, events in itertools.groupby(sorted(sngl_inspiral_table, key = lambda row: row.ifo), lambda event: event.ifo):
+			time_slide_graph.push(instrument, tuple(events), snglcoinc.segments.PosInfinity)
+	else:
+		# slower diagnostic version.  simulate an online
+		# incremental analysis by pushing events into the graph in
+		# time order and collecting candidates as we go.  we still
+		# do the final flush operation below.
+		for instrument, events in itertools.groupby(sorted(sngl_inspiral_table, key = lambda row: (row.end, row.ifo)), lambda event: event.ifo):
+			events = tuple(events)
+			if time_slide_graph.push(instrument, events, max(event.end for event in events)):
+				for node, events in time_slide_graph.pull(coinc_sieve = ntuple_comparefunc):
+					coinc_tables.append_coinc(*coinc_tables.coinc_rows(process_id, node.time_slide_id, events, seglists = seglists))
+
+	#
+	# retrieve all remaining coincidences.
+	#
+
+	for node, events in time_slide_graph.pull(coinc_sieve = ntuple_comparefunc, flush = True):
+		coinc_tables.append_coinc(*coinc_tables.coinc_rows(process_id, node.time_slide_id, events, seglists = seglists))
 
 	#
 	# done
