@@ -1,5 +1,3 @@
-#!/usr/bin/env python
-#
 # Copyright (C) 2011--2014 Karl Wette
 #
 # This program is free software; you can redistribute it and/or modify
@@ -14,8 +12,8 @@
 #
 # You should have received a copy of the GNU General Public License
 # along with with program; see the file COPYING. If not, write to the
-# Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
-# MA  02111-1307  USA
+# Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+# MA  02110-1301  USA
 
 """Generate the swig<package>.i interface file for a given LAL subpackage
 
@@ -25,8 +23,6 @@ This also handles on-the-fly symbol renaming, mainly to make the SWIG interface
 more natural for high-level languages that support namespaces.
 """
 
-from __future__ import print_function
-
 __author__ = "Karl Wette <karl.wette@ligo.org>"
 __copyright__ = 'Copyright (C) 2011--2014 Karl Wette'
 
@@ -456,15 +452,26 @@ def get_swig_attr(elem, name):
             return attr_elem.get('value')
 
 
-def write_interface_file(file, package, symbols, dependencies, headers):
+def write_interface_file(swig_version, iface_file, package, symbols, dependencies, headers):
     """Write SWIG interface file
     """
     def fprint(*args, **kwargs):
-        kwargs["file"] = file
+        kwargs["file"] = iface_file
         return print(*args, **kwargs)
 
-    fprint('// {}: generated by {}'.format(file.name, sys.argv[0]))
+    swiglal_config_undef = 'swiglal_{}Config_undef.h'.format(package)
+
+    # header
+    fprint('// {}: generated by {}'.format(iface_file.name, sys.argv[0]))
     fprint('%module {};'.format(package.lower()))
+
+    # check version
+    swig_version_hex = "0x" + "".join(["{:02d}".format(int(v)) for v in swig_version.split(".")])
+    fprint("#if SWIG_VERSION != {}".format(swig_version_hex))
+    fprint("%warn \"999:{} requires SWIG version {}\"".format(iface_file.name, swig_version))
+    fprint("#endif")
+
+    # import common code
     fprint('%include <lal/SWIGCommon.i>')
 
     # import dependent modules
@@ -476,7 +483,8 @@ def write_interface_file(file, package, symbols, dependencies, headers):
     # include interface headers in wrapping code
     fprint('%header %{')
     for header in headers:
-        fprint('#include <lal/%s>' % header)
+        if header != swiglal_config_undef:
+            fprint('#include <lal/%s>' % header)
     fprint('%}')
 
     # add renames
@@ -531,9 +539,10 @@ def write_interface_file(file, package, symbols, dependencies, headers):
     # include interface headers, and clear SWIGLAL() macros afterwards
     fprint('%include <lal/SWIG{}Alpha.i>'.format(package))
     for header in headers:
-        fprint('%include <lal/{}>'.format(header))
-        for macro_name in symbols.clear_macros[header]:
-            fprint('SWIGLAL_CLEAR({});'.format(macro_name))
+        if header != swiglal_config_undef:
+            fprint('%include <lal/{}>'.format(header))
+            for macro_name in symbols.clear_macros[header]:
+                fprint('SWIGLAL_CLEAR({});'.format(macro_name))
     fprint('%include <lal/SWIG{}Omega.i>'.format(package))
 
     # add extensions to structs, e.g. constructors and destructors
@@ -549,6 +558,12 @@ def write_interface_file(file, package, symbols, dependencies, headers):
             ),
         )
 
+    # include header which provides #undef symbols from configuration header
+    with open(swiglal_config_undef, "r") as undef_file:
+        for line in undef_file:
+            if line.startswith('#'):
+                fprint(line.strip())
+
 
 # -- parse command line -------------------------
 
@@ -558,6 +573,7 @@ def create_parser():
     parser = argparse.ArgumentParser(
         description=__doc__,
     )
+    parser.add_argument("swig_version", help="SWIG version")
     parser.add_argument("package_name", help="name of package")
     parser.add_argument("dependencies", help="list of package dependencies")
     parser.add_argument("function_prefixes", help="function prefices")
@@ -599,9 +615,10 @@ if __name__ == "__main__":
     symbols.find_destructors()
 
     # write interface file
-    with open(args.output_iface, "w") as file:
+    with open(args.output_iface, "w") as iface_file:
         write_interface_file(
-            file,
+            args.swig_version,
+            iface_file,
             args.package_name,
             symbols,
             args.dependencies,
